@@ -34,7 +34,7 @@ typedef struct
 {
     GObjectClass parent_class;
 
-    void (*start_scan) (SimpleScan *ui, const gchar *device, gint dpi, const gchar *document_type, gboolean continuous);
+    void (*start_scan) (SimpleScan *ui, ScanOptions *options);
     void (*stop_scan) (SimpleScan *ui);
     void (*save) (SimpleScan *ui, const gchar *format);
     void (*email) (SimpleScan *ui, const gchar *profile);
